Density, distribution function, quantile function and random number generation for the carrier distributions of the extended Generalized Pareto distributions.
vector of observations (degp2.G), probabilities (qegp2.G) or quantiles (pegp2.G), in \([0,1]\)
mixture probability for model type 4
shape parameter for type 1, 3 and 4
additional parameter for type 2, 3 and 4
integer between 0 to 5 giving the model choice
logical; should the log-density be returned (default to FALSE)?
sample size
sample of uniform; if provided, the data will be used in place of new uniform random variates
numeric vector of length 2 containing the lower and upper bound for censoring
logical; which method to use for sampling in model of type 4?
pegp2.G(u, type=1,prob, kappa, delta)
degp2.G(u,type=1, prob=NA, kappa=NA, delta=NA, log=FALSE)
qegp2.G(u,type=1, prob=NA,kappa=NA,delta=NA)
regp2.G(n,prob=NA,kappa=NA,delta=NA,type=1,unifsamp=NULL,direct=FALSE,censoring=c(0,1))