Information matrix of the generalized extreme value distribution (quantile/mean of N-block maxima parametrization)
gevN.infomat(par, dat, method = c("obs", "exp"), qty = c("mean",
"quantile"), N, q = 0.5, nobs = length(dat))vector of loc, quantile/mean of N-block maximum and shape
sample vector
string indicating whether to calculate the q quantile or the mean
probability, corresponding to \(q\)th quantile of the N-block maximum