gpd.Fscore: Firth's modified score equation for the generalized Pareto distribution
Description
Firth's modified score equation for the generalized Pareto distribution
Usage
gpd.Fscore(par, dat, method = c("obs", "exp"))Arguments
par
vector of scale and shape
method
string indicating whether to use the expected ("exp") or the observed ("obs" - the default) information matrix.
References
Firth, D. (1993). Bias reduction of maximum likelihood estimates, Biometrika, 80(1), 27--38.