Function returning the density of an n sample from the GP distribution.
gpd.ll.optim returns the negative log likelihood parametrized in terms of log(scale) and shape
in order to perform unconstrained optimization
gpd.ll(par, dat, tol = 1e-05)gpd.ll.optim(par, dat, tol = 1e-05)
vector of scale and shape
sample vector
numerical tolerance for the exponential model