Learn R Programming

mev (version 1.3)

mev-package: Multivariate Extreme Value Distributions

Description

Exact simulation from max-stable processes and multivariate extreme value distributions for various parametric models.

Arguments

concept

  • multivariate extreme value
  • exact simulation
  • max-stable process
  • logistic
  • Dirichlet
  • extremal Student process
  • Dirichlet mixture
  • Coles and Tawn model
  • bilogistic
  • negative logistic
  • negative bilogistic
  • Brown-Resnick process

Details

The package allows exact generation of multivariate extreme value vectors or max-stable processes. For the latter, the user can provide a variogram function along with a set of locations that serve as input. Models implemented include the 1-parameter logistic and negative logistic as described in the article, the bilogistic and Coles and Tawn extremal Dirichlet model using the algorithm of Boldi (2009) and the Dirichlet mixture. The extremal Student and Husler-Reiss (Brown-Resnick) models are also implemented.

A Dirichlet and a multinormal generator are part of the internal functions and are exported.

References

Dombry, Engelke and Oesting (2015) Exact simulation of max-stable processes arXiv:1506.04430v1, 1--24.

Boldi (2009). A note on the representation of parametric models for multivariate extremes. Extremes 12, 211--218.