Learn R Programming

mev (version 1.3)

rmev: Exact simulations of multivariate extreme value distributions

Description

Implementation of the random number generators for multivariate extreme-value distributions and max-stable processes based on the two algorithms described in Dombry, Engelke and Oesting (2015).

Usage

rmev(n, d, param, asy, sigma, model = c("log", "alog", "neglog", "aneglog",
  "bilog", "negbilog", "hr", "xstud", "smith", "ct", "dirmix"), alg = c("ef",
  "sm"), weights, vario, loc, grid = FALSE)

Arguments

n
number of observations
d
dimension of sample
param
parameter vector for the logistic, bilogistic, negative bilogistic and extremal Dirichlet (Coles and Tawn) model. Parameter matrix for the Dirichlet mixture. Degree of freedoms for extremal student model.
asy
list of asymmetry parameters, as in rmvevd, of $2^d-1$ vectors of size corresponding to the power set of d, with sum to one constraints.
sigma
covariance matrix for Husler-Reiss and extremal Student-t distributions
model
choice between 1-parameter logistic and negative logistic, asymmetric logistic and negative logistic, bilogistic and the extremal Dirichlet model of Coles and Tawn, the Brown-Resnick (which generate the Husler-Reiss MEV distribution), Smith and extremal S
alg
algorithm, either simulation via extremal function or via the spectral measure. The extremal Dirichlet model is only implemented with sm.
weights
vector of length m for the m mixture components. Must sum to one
vario
function specifying the variogram. Used only if provided in conjonction with loc and if sigma is missing
loc
d by k matrix of location, used as input in the variogram vario or as parameter for the Smith model. If grid is TRUE, unique entries should be supplied.
grid
Logical. TRUE if the coordinates are two-dimensional grid points (spatial models).

Value

  • an n by d exact sample from the corresponding multivariate extreme value model

Details

The vector param differs depending on the model
  • log: one dimensional parameter greater than 1
  • alog:$2^d-d-1$dimensional parameter fordep. Values are recycled if needed.
  • neglog: one dimensional positive parameter
  • aneglog:$2^d-d-1$dimensional parameter fordep. Values are recycled if needed.
  • bilog:d-dimensional vector of parameters in$[0,1]$
  • negbilog:d-dimensional vector of negative parameters
  • ct:d-dimensional vector of positive (a)symmetry parameters. Alternatively, a$d+1$vector consisting of thedDirichlet parameters and the last entry is an index of regular variation in(0, 1]treated as scale
  • xstud: one dimensional parameter corresponding to degrees of freedomalpha
  • dirmix:dbym-dimensional matrix of positive (a)symmetry parameters

References

Dombry, Engelke and Oesting (2015). Exact simulation of max-stable processes, arXiv:1506.04430v1, 1--24.

See Also

rmevspec, rmvevd, rbvevd

Examples

Run this code
set.seed(1)
rmev(n=100, d=3, param=2.5, model="log", alg="ef")
rmev(n=100, d=4, param=c(0.2,0.1,0.9,0.5), model="bilog", alg="sm")
## Spatial example using variogram, from Clement Dombry
#Variogram gamma(h) = scale*||h||^alpha
scale <- 0.5; alpha <- 1
vario <- function(x) scale*sqrt(sum(x^2))^alpha
#grid specification
grid.loc <- as.matrix(expand.grid(runif(4), runif(4)))
rmev(n=100, vario=vario,loc=grid.loc, model="hr")
#Example with a grid (generating an array)
rmev(n=10, sigma=cbind(c(2,1),c(1,3)), loc=cbind(runif(4),runif(4)),model="smith", grid=TRUE)
## Example with Dirichlet mixture
alpha.mat <- cbind(c(2,1,1),c(1,2,1),c(1,1,2))
rmev(n=100, param=alpha.mat, weights=rep(1/3,3), model="dirmix")

Run the code above in your browser using DataLab