Learn R Programming

mev (version 1.3)

mvrnorm: Multivariate Normal distribution sampler

Description

Sampler derived using the eigendecomposition of the covariance matrix Sigma. The function uses the Armadillo random normal generator

Usage

mvrnorm(n, mu, Sigma)

Arguments

n
sample size
mu
mean vector. Will set the dimension
Sigma
a square covariance matrix, of same dimension as mu. No sanity check is performed to validate that the matrix is p.s.d., so use at own risk

Value

  • an n sample from a multivariate Normal distribution

Examples

Run this code
mvrnorm(n=10, mu=c(0,2), Sigma=diag(2))

Run the code above in your browser using DataLab