Learn R Programming

mev (version 1.3)

rdir: Random variate generation for Dirichlet distribution on $S_{d}$

Description

A function to sample Dirichlet random variables, based on the representation as ratios of Gamma. Note that the RNG will generate on the full simplex and the sum to one constraint is respected here

Usage

rdir(n, alpha, normalize = TRUE)

Arguments

n
sample size
alpha
vector of parameter
normalize
boolean. If FALSE, the function returns Gamma variates with parameter alpha.

Value

  • sample of dimension d (size of alpha) from the Dirichlet distribution.

Examples

Run this code
rdir(n=100, alpha=c(0.5,0.5,2),TRUE)
rdir(n=100, alpha=c(3,1,2),FALSE)

Run the code above in your browser using DataLab